@@ -61,7 +61,7 @@ function (B, P, ps, yy, w, lambdax, lambdap, center)
         nw <- sum(w != w0)
         if (nw == 0) 
             break
-        cat(it, nw, "\n")
+
     }
     pcoef = matrix(pcoef, nrow = B.size)
     if (center) {
@@ -102,6 +102,6 @@ function (B, P, ps, yy, w, lambdax, lambdap, center)
             Z[[i]] = Bg %*% ag
             dim(Z[[i]]) = c(my, np)
         }
-    return(list(coef = t(pcoef), fit = pfit, hatma = hat(model$qr), 
+    return(list(coef = t(pcoef), fit = pfit, hatma = hat(model$qr)[1:length(yy)], 
         curves = Z, intercept = intercept))
 }
